@@ -246,6 +246,8 @@ eog_image_init (EogImage *img)
 	img->priv->modified = FALSE;
 	img->priv->status_mutex = g_mutex_new ();
 	img->priv->status = EOG_IMAGE_STATUS_UNKNOWN;
+	img->priv->prev_status = EOG_IMAGE_STATUS_UNKNOWN;
+	img->priv->is_monitored = FALSE;
 	img->priv->undo_stack = NULL;
 	img->priv->trans = NULL;
 	img->priv->trans_autorotate = NULL;
@@ -414,6 +416,24 @@ eog_image_real_transform (EogImage     *img,
 	}
 }
 
+static gboolean
+check_loader_threadsafety (GdkPixbufLoader *loader, gboolean *result)
+{
+	GdkPixbufFormat *format;
+	gboolean ret_val = FALSE;
+
+	format = gdk_pixbuf_loader_get_format (loader);
+	if (format) {
+		ret_val = TRUE;
+		if (result) 
+		/* FIXME: We should not be accessing this struct internals
+ 		 * directly. Keep track of bug #469209 to fix that. */
+			*result = format->flags & GDK_PIXBUF_FORMAT_THREADSAFE;
+	}
+
+	return ret_val;	
+}
+
 static void
 eog_image_pre_size_prepared (GdkPixbufLoader *loader,
 			     gint width,
@@ -421,22 +441,13 @@ eog_image_pre_size_prepared (GdkPixbufLoader *loader,
 			     gpointer data)
 {
 	EogImage *img;
-	GdkPixbufFormat *format;
 
 	eog_debug (DEBUG_IMAGE_LOAD);
 
 	g_return_if_fail (EOG_IS_IMAGE (data));
 
 	img = EOG_IMAGE (data);
-
-	format = gdk_pixbuf_loader_get_format (loader);
-
-	if (format) {
-		/* FIXME: We should not be accessing this struct internals
- 		 * directly. Keep track of bug #469209 to fix that. */
-		img->priv->threadsafe_format =
-			(format->flags & GDK_PIXBUF_FORMAT_THREADSAFE);
-	}
+	check_loader_threadsafety (loader, &img->priv->threadsafe_format);
 }
 
 static void
@@ -982,6 +993,8 @@ eog_image_real_load (EogImage *img,
 	buffer = g_new0 (guchar, EOG_IMAGE_READ_BUFFER_SIZE);
 	
 	if (read_image_data || read_only_dimension) {
+		gboolean checked_threadsafety = FALSE;
+
 		loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, error);
 	
 		if (*error) {
@@ -989,15 +1002,20 @@ eog_image_real_load (EogImage *img,
 			*error = NULL;
 
 			loader = gdk_pixbuf_loader_new (); 
+		} else {
+			/* The mimetype-based loader should know the
+			 * format here already. */
+			checked_threadsafety = check_loader_threadsafety (loader, &priv->threadsafe_format);
 		}
 
 		/* This is used to detect non-threadsafe loaders and disable
  		 * any possible asyncronous task that could bring deadlocks
  		 * to image loading process. */
-		g_signal_connect (loader, 
-				  "size-prepared", 
-				  G_CALLBACK (eog_image_pre_size_prepared),
-				  img);
+		if (!checked_threadsafety)
+			g_signal_connect (loader, 
+					  "size-prepared",
+					  G_CALLBACK (eog_image_pre_size_prepared),
+					  img);
 
 		g_signal_connect_object (G_OBJECT (loader), 
 					 "size-prepared", 
@@ -1091,9 +1109,15 @@ eog_image_real_load (EogImage *img,
 	}
 
 	if (read_image_data || read_only_dimension) {
-		/* Close silently in order to support partial
-		 * images as well. */
-		gdk_pixbuf_loader_close (loader, NULL);
+		if (failed) {
+			gdk_pixbuf_loader_close (loader, NULL);
+		} else if (!gdk_pixbuf_loader_close (loader, error)) {
+			if (gdk_pixbuf_loader_get_pixbuf (loader) != NULL) {
+				/* Clear error in order to support partial
+				 * images as well. */
+				g_clear_error (error);
+			}
+	        }
         }
 
 	g_free (buffer);
@@ -1572,6 +1596,17 @@ eog_image_save_by_info (EogImage *img, EogImageSaveInfo *source, GError **error)
 
 	priv = img->priv;
 
+	/* FIXME: Because of a bug in gnome-vfs file monitoring, we need to avoid
+         * an image that is being saved to be removed and re-added by the monitor
+         * handler. We do this by setting the image's status to "saving" and, in
+         * case the image is being monitored, the status is only restored after the
+         * "fake" image deletion is notified by gnome-vfs. Same aproach is used in
+         * eog_image_save_as_by_info(). See bug #46830. */
+	priv->prev_status = priv->status;
+
+	/* Image is now being saved */
+	priv->status = EOG_IMAGE_STATUS_SAVING;
+
 	/* see if we need any saving at all */
 	if (source->exists && !source->modified) {
 		return TRUE;
@@ -1620,6 +1655,11 @@ eog_image_save_by_info (EogImage *img, EogImageSaveInfo *source, GError **error)
 
 	g_free (tmpfile);
 
+	/* Restore previous status only if is not monitored image */
+	if (!priv->is_monitored) {
+		priv->status = priv->prev_status;
+	}
+
 	return success;
 }
 
@@ -1705,6 +1745,8 @@ eog_image_save_as_by_info (EogImage *img, EogImageSaveInfo *source, EogImageSave
 
 	priv = img->priv;
 
+	priv->prev_status = priv->status;
+
 	/* fail if there is no image to save */
 	if (priv->image == NULL) {
 		g_set_error (error, 
@@ -1759,6 +1801,11 @@ eog_image_save_as_by_info (EogImage *img, EogImageSaveInfo *source, EogImageSave
 	tmp_file_delete (tmpfile);
 	g_free (tmpfile);
 
+	/* Restore previous status only if is not monitored image */
+	if (!priv->is_monitored) {
+		priv->status = priv->prev_status;
+	}
+
 	return success;
 }
 
@@ -1999,6 +2046,30 @@ eog_image_get_uri_for_display (EogImage *img)
 	return str;
 }
 
+EogImageStatus
+eog_image_get_status (EogImage *img)
+{
+	g_return_val_if_fail (EOG_IS_IMAGE (img), EOG_IMAGE_STATUS_UNKNOWN);
+
+	return img->priv->status;
+}
+
+void
+eog_image_restore_status (EogImage *img)
+{
+	g_return_if_fail (EOG_IS_IMAGE (img));
+
+	img->priv->status = img->priv->prev_status;
+}
+
+void
+eog_image_set_is_monitored (EogImage *img, gboolean is_monitored)
+{
+	g_return_if_fail (EOG_IS_IMAGE (img));
+
+	img->priv->is_monitored = is_monitored;
+}
+
 void
 eog_image_data_ref (EogImage *img)
 {
