@@ -477,7 +477,7 @@ eog_properties_dialog_init (EogPropertiesDialog *prop_dlg)
 	priv->update_page = FALSE;
 
 	eog_dialog_construct (EOG_DIALOG (prop_dlg),
-			      "eog.glade",
+			      "eog-image-properties-dialog.glade",
 			      "eog_image_properties_dialog");
  
 	eog_dialog_get_controls (EOG_DIALOG (prop_dlg), 
