@@ -39,7 +39,8 @@ typedef struct _EogThumbViewClass EogThumbViewClass;
 typedef struct _EogThumbViewPrivate EogThumbViewPrivate;
 
 typedef enum {
-	EOG_THUMB_VIEW_SELECT_LEFT = 0,
+	EOG_THUMB_VIEW_SELECT_CURRENT = 0,
+	EOG_THUMB_VIEW_SELECT_LEFT,
 	EOG_THUMB_VIEW_SELECT_RIGHT,
 	EOG_THUMB_VIEW_SELECT_FIRST,
 	EOG_THUMB_VIEW_SELECT_LAST
@@ -61,6 +62,9 @@ GtkWidget  *eog_thumb_view_new 			    (void);
 void	    eog_thumb_view_set_model 		    (EogThumbView *view, 
 						     EogListStore *store);
 
+void        eog_thumb_view_set_item_height          (EogThumbView *view,
+						     gint          height);
+
 guint	    eog_thumb_view_get_n_selected 	    (EogThumbView *view);
 
 EogImage   *eog_thumb_view_get_first_selected_image (EogThumbView *view);
