@@ -108,9 +108,7 @@ eog_util_make_valid_utf8 (const gchar *str)
 	}
 
 	g_string_append (string, remainder);
-	/* FIXME: Can't add this string for 2.20 anymore. Uncomment 
-	 * this after stable branching. */
-	/* g_string_append (string, _(" (invalid Unicode)")); */
+	g_string_append (string, _(" (invalid Unicode)"));
 
 	g_assert (g_utf8_validate (string->str, -1, NULL));
 
@@ -189,8 +187,7 @@ eog_util_string_array_make_absolute (gchar **files)
 	
 	int size = g_strv_length (files);
 	
-	/* Ensure new list is NULL-terminated */
-	abs_files = g_new0 (gchar *, size+1);
+	abs_files = g_new0 (gchar *, size);
 	
 	for (i = 0; i < size; i++) {
 		abs_files[i] = gnome_vfs_make_uri_from_input_with_dirs (files[i],
